/* blacklist.h -- Part of the Visitors Web Log Analyzer
 * Copyright (C) 2005 Salvatore Sanfilippo
 *
 * NOTE:
 * 
 * This fail was obtained as a modification of the
 * MT-Blacklist Master Copy, see
 * http://www.jayallen.org/comment_spam/blacklist.txt
 *
 * It is modified for visitors in order to make regexps
 * simpler direct matches that can be performed with strstr()
 * C lib function.
 */

#define VI_BLACKLIST_LEN (sizeof(vi_blacklist)/sizeof(char*))

static char *vi_blacklist[] = {
"lsotr",
"lostr",
"blowjob",
"enlargement",
"sonneries",
"levitra",
"lolita",
"phentermine",
"viagra",
"zyban",
"valtex",
"xenical",
"adipex",
"meridia",
"netfirms",
"apartment",
"milf",
"hunter",
"moms",
"fucking",
"casino",
"prozac",
"zoloft",
"xanax",
"valium",
"hydrocodone",
"vicodin",
"paxil",
"vioxx",
"ragazze",
"ultram",
"tenuate",
"tramadol",
"pheromones",
"phendimetrazine",
"ionamin",
"ortho",
"tricyclen",
"retin",
"valtrex",
"zyrtec",
"ambien",
"flonase",
"allegra",
"didrex",
"renova",
"bontril",
"nexium",
"-4-you.info",
"-4u.info",
"-mobile-phones.org",
"-site.info",
".gb.com",
".lycos.de",
".static.net",
"-casino.com",
"-poker.com",
"-porn.com"
"01-beltonen.com",
"01-klingeltoene.at",
"01-klingeltoene.de",
"01-loghi.com",
"01-logo.com",
"01-logot.com",
"01-logotyper.com",
"01-melodia.com",
"01-melodias.com",
"01-ringetone.com",
"01-ringsignaler.com",
"01-ringtone.com",
"01-ringtones.us",
"01-soittoaanet.com",
"01-suonerie.com",
"01-toque.com",
"01ringtones.co.uk",
"0adult-cartoon.com",
"0adult-manga.com",
"0cartoon-porn.com",
"0cartoon-sex.com",
"0cartoon.com",
"0casino-online.com",
"0casinoonline.com",
"0catch.com",
"0free-hentai.com",
"0freehentai.com",
"0hentai-anime.com",
"0hentai-manga.com",
"0hentaimanga.com",
"0livesex.com",
"0manga-porno.com",
"0manga-sesso.com",
"0manga.com",
"0sesso-amatoriale.com",
"0sesso-orale.biz",
"0sesso.biz",
"0sesso.us",
"0sessoanale.com",
"0sessogratis.us",
"0sex-toons.com",
"0sfondi-desktop.com",
"0sfondi.com",
"0suonerie.com",
"0tatuaggi.com",
"0toons.com",
"0video-porno.com",
"0xxx-cartoon.com",
"1-bignaturals.com",
"1-cumfiesta.com",
"1-klingeltone.com",
"1-online-poker.us",
"1-poker-games.biz",
"1-welivetogether.com",
"1-wholesale-distributor.com",
"100-sex.com",
"100free.com",
"100hgh.com",
"101pills.com",
"108bikes.com",
"123-home-improvement-equity-loans.com",
"123-sign-making-equipment-and-supplies.com",
"123onlinepoker.com",
"123sessogratis.com",
"125mb.com",
"15668.com",
"16pp.com",
"1a1merchantaccounts.com",
"1asphost.com",
"1concerttickets.com",
"1footballtickets.com",
"1freespot.com",
"1on8.co.uk",
"1on8.com",
"1st-advantage-credit-repair.com",
"1st-auto-insurance-4u.com",
"1st-host.org",
"1st-payday-loans.net",
"1st-phonecard.com",
"1st-poker-online.com",
"1st-printer-ink-cartridge.com",
"1st-shemale-sex.com",
"1stincomeracing.co.uk",
"1stindustrialdirectory.com",
"1stlookcd.com",
"1xp6z.com",
"20fr.com",
"216.130.167.230",
"24-hour-fitness-online.com",
"247-rx.net",
"2ndmortgageinterestrates.com",
"2teens.net",
"2twinks.com",
"2y.net",
"2zj.cn",
"3-day-diet-plan.com",
"321cigarettes.com",
"333-poker.com",
"3333.ws",
"365jp.com",
"38ha.com",
"3host.com",
"3sixtyfour.com",
"3yaoi.com",
"404host.com",
"404servers.com",
"41b.net",
"42tower.ws",
"444-poker.com",
"4hs8.com",
"4mg.com",
"4result.net",
"4u-topshelfpussy.com",
"4womenoftheworld.com",
"51.net",
"51asa.com",
"555-poker.com",
"5amateurs.com",
"65.217.108.182",
"666-gambling.com",
"69.61.11.163",
"6p.org.uk",
"6x.to",
"7host.com",
"7p.org.uk",
"7yardsweb.com",
"888-online-poker.com",
"888cas.com",
"888jack.com",
"88aabb.com",
"8bit.co.uk",
"8gold.com",
"8k.com",
"8yardsweb.com",
"911easymoney.com",
"911pills.info",
"989888.com",
"9p.org.uk",
"a--e.com",
"a-1-versicherungsvergleich.de",
"a-pics.net",
"a-purfectdream-expression.com",
"a-stories.com",
"a1-mortgage-finder.com",
"a1cellphoneaccessories.info",
"a1digitalcameras.info",
"a1metalbuildings.info",
"a1steelbuildings.info",
"a1timemanagement.info",
"abc3x.com",
"abnehmen-ganz-sicher.com",
"abocams.de",
"aboutgrouphomes.com",
"abymetro.org.uk",
"academyofmusic.us",
"acceptcreditcardsonlineinternetmerchantaccountservices.com",
"acceptcreditcardsrealtime.com",
"accompagnatrici.cc",
"achtung.hopto.org",
"acornfm.com",
"acornwebdesign.co.uk",
"acrs.us",
"activerx.com",
"acyclovir.net",
"addictinggames.com",
"aducasher.spb.ru",
"adult-dvd-dot.com",
"adult-dvds-dot.com",
"adult-free-webcams.com",
"adult-friend.info",
"adult-games.name",
"adult-manga.org",
"adult-porno.us",
"adultfreehosting.com",
"adultfriendfinder.com",
"adultfriendfindernow.com",
"adultfriendfindersite.com",
"adultfriendsite.com",
"adulthostpro.com",
"adultlingerieuk.com",
"adultnonstop.com",
"adultporncentral.net",
"adultserviceproviders.com",
"adultshare.com",
"advantage-quotes.com",
"aektschen.de",
"aesthetics.co.il",
"affilino.net",
"afreeserver.com",
"ahbabe.com",
"aimite.com",
"airfare-links.net",
"airshow-china.com.cn",
"alawna.blogspot.com",
"all-calmortgage.com",
"all-debt-consolidation.org",
"all-fioricet.com",
"all-gay-porn.us",
"all-poker-online",
"all-we-live-together.com",
"allago.de",
"allfind.us",
"allinsurancetype.com",
"allmagic.ru",
"alloha.info",
"allohaweb.com",
"allthediets.com",
"allthroating.com",
"almacenpc.com",
"alphacarolinas.org",
"alright.com.ru",
"alumnicards.com",
"amateur-lesbian.us",
"amateur-movie.us",
"amateur-naked.us",
"amateur-porn-gallery.com",
"amateur-porno.us",
"amateur-site.us",
"amateur-thumbnail.com",
"amateur-thumbs.net",
"amateurjerkoff.org",
"amateurs-xxx.us",
"amateurs.r00m.com",
"amateursuite.com",
"amazing-satellite-tv-deals.info",
"americacashfast.com",
"american-single-dating.com",
"americancdduplication.com",
"americanpaydayloans.net",
"americastgp.com",
"amoxicillin-online.net",
"anal-sex-pictures.us",
"analloverz.com",
"andyedf.de",
"angenehmen-aufenthalt.de",
"animal-fuck.org",
"animal-porn.ws",
"animalsex-movies-archive.com",
"animalsex-pics-gallery.com",
"anime-adult.us",
"anime-hentai-porn.com",
"anime-manga.us",
"anime-porn-sex-xxx.com",
"anime-porn.name",
"anime-sex-cartoon-porn.com",
"annunci-coppie.net",
"annunci-erotici.net",
"annunci-erotici.org",
"annunci-personali.org",
"annunci-sesso.org",
"annunci-sesso.us",
"annuncisesso.us",
"anonsi.com",
"anonymous-blogger.com",
"ansar-u-deen.org",
"anti-exploit.com",
"anticlick.com.ru",
"anuntisinmobiliaria.com",
"anxietydisorders.biz",
"anylight4u.com",
"anything4health.com",
"anzwers.org",
"aol-com.us",
"ap8.com",
"apecceosummit2003.com",
"apollopatch.com",
"apornhost.com",
"apply-to-green-card.org",
"appollo.org",
"approval-loan.com",
"aquari.ru",
"aquatyca.net",
"arcsecurity.co.uk",
"area-code-npa-nxx.com",
"argendrom.com",
"armor2net.com",
"aromacc.com",
"artsculpture.org",
"aseman.weblogs.us",
"asian-girls-porn-sex.com",
"asian-girls.name",
"asian-nude.blogspot.com",
"asian-sex-woman.com",
"asianbum.com",
"ass-picture.us",
"assserver.com",
"at-capstone.com",
"atkins-diet-center.com",
"atkinsexpert.com",
"atkpremium.net",
"atkpremium.org",
"atlanta2000.org",
"atlas-pharmacy.com",
"auctionmoneymakers.com",
"auktions-uebersicht.de",
"australia-online-travel.com",
"austria-travels.info",
"auto-insurance-links.net",
"auto-loans-usa.biz",
"autodetailproducts.com",
"autodirektversicherung.com",
"autofinanzierung-autokredit.de",
"autofinanzierung-zum-festzins.de",
"autohandelsmarktplatz.de",
"autokredit-autofinanzierung.de",
"autokredit-tipp.de",
"automotive.com",
"autumn-jade.com",
"avon-one.com",
"azian.org",
"b-witchedcentral.co.uk",
"ba2000.com",
"babes-d.com",
"babes-plus.com",
"baby-perfekt.de",
"babymarktplatz-aktiv.de",
"back-room-facials.angelcities.com",
"background-check.info",
"backroom-facials.150m.com",
"backseatbangers",
"bad-movies.net",
"bad-passion.com",
"bahraichfun.com",
"bali-dewadewi-tours.com",
"bali-hotels.co.uk",
"balidiscovery.org",
"balivillas.net",
"balltaas.com",
"banialoba3w.150m.com",
"banned-pics.com",
"bannedhome.com",
"barcodes.cn",
"bare.org",
"barely-legal-teenb.com",
"barely-legald.com",
"barelylegalgirlsex.com",
"bargainfindsonebay.com",
"bargeld-tipp.de",
"basi-musicali.com",
"basketball--betting.net",
"bast3.ru",
"batukaru.",
"bbwclips.com",
"bccinet.org",
"bdsm-story.blogspot.com",
"beastiality-animal-sex-stories.com",
"beastiality-stories.net",
"beastsex-movies.com",
"beauty-farm.net",
"bedding-etc.com",
"belinking.com",
"belle-donne.biz",
"belle-ragazze.net",
"belle-ragazze.org",
"belleragazze.biz",
"belleragazze.org",
"bellissime-donne.com",
"bellissime-donne.net",
"bellissimedonne.com",
"bellissimedonne.org",
"beltonen-logos-spel.com",
"benessere.us",
"berwickfoundation.org",
"best-buy-cialis.com",
"best-cell-phone-batteries.info",
"best-cialis-source.com",
"best-deals-blackjack.info",
"best-deals-casino.info",
"best-deals-cheap-airline-tickets.info",
"best-deals-diet.info",
"best-deals-flowers.info",
"best-deals-hotels.info",
"best-deals-online-gambling.info",
"best-deals-online-poker.info",
"best-deals-poker.info",
"best-deals-roulette.info",
"best-deals-weight-loss.info",
"best-e-site.com",
"best-gambling.biz",
"best-high-speed-internet.com",
"best-internet-bingo.com",
"best-pharmacy.us",
"best-result-fast.com",
"bestasianteens.com",
"bestdims.com",
"bestdvdclubs.com",
"bestgamblinghouseonline.com",
"besthandever.com",
"bestiality-pics.org",
"bestialitylinks.org",
"bestits.net",
"bestlowmortgagerates",
"bestonline-medication.com",
"bestonline-medication.net",
"bestonline-shopping.com",
"bestpornhost.com",
"bet-on-horseracing.com",
"beverlyhillspimpandhos.com",
"beverlyhillspimpsandhos.com",
"biexperience.org",
"big-black-butts.net",
"big-breast-success.com",
"big-hooters.net",
"big-natural-boobs.us",
"big-naturals-4u.com",
"big-rant.com",
"bigbras-club.com",
"bigmag.com.ua",
"bigmoms.com",
"bigtitchaz.com",
"bigyonet.com",
"bildmitteilung.us",
"billigfluege-billige-fluege.de",
"bingo-net.com",
"bio-snoop.com",
"birth-control-links.com",
"bizhat.com",
"bj-cas.cn",
"bj-fyhj.com",
"bj-hchy.com",
"bjerwai.com",
"bjgift.com",
"bjkhp.com",
"bjxhjy.com",
"bla5.com",
"black-amateur-cock.net",
"black-dick-white-slut.com",
"black-girls.blowsearch.ws",
"black-jack-4u.net",
"black-jack-trx.com",
"blackbusty.com",
"blackjack-123.com",
"blackjack-21.ws",
"blackjack-4u.net",
"blackjack-777.net",
"blackjack-8.com",
"blackjack-dot.com",
"blackjack-homepage.com",
"blackjack-p.com",
"blackjack-play-blackjack.com",
"blackjack-winner.net",
"blackjack.fm",
"blackjack777.net",
"blackjacksite.net",
"blahblah.tk",
"blk-web.de",
"bllogspot.com",
"blog-tips.com",
"bloglabs.biz",
"blogman.biz",
"blogmen.net",
"blogspam.org",
"blonde-pussy.us",
"blonde-video.us",
"blonde-xxx.us",
"blondes2fuck.com",
"blumengruss-onlineshop.de",
"blumenshop-versand.de",
"bnetsol.com",
"body-jewelry.reestr.net",
"body-piercing.softinterop.com",
"bodyjock.com",
"bon-referencement.com",
"bondage-story.blogspot.com",
"boobmorning.com",
"boobspost.com",
"booktextone.com",
"boom.ru",
"borindonaragara.com",
"boysgonebad.net",
"brazilbang.biz",
"breast-augmentation.top-big-tits.com",
"briana-banks-dot.com",
"british-hardcore.net",
"bszz.com",
"bueroversand-xxl.de",
"bugaboo-stroller.com",
"build-penis.com",
"bulkemailsoft.com",
"burningcar.net",
"burundonamagara.com",
"business-grants.org",
"business-web-site.net",
"businessgrants.biz",
"busty-models.us",
"bustyangelique.com",
"bustydustystash.com",
"bustykerrymarie.com",
"butalbital.org",
"buy-2005-top.com",
"buy-2005.com",
"buy-adult-sex-toys.com",
"buy-adult-toys.biz",
"buy-car-insurance-4-us.com",
"buy-ceramics.com",
"buy-cheapest-lexapro-side-effects-noprescription.biz",
"buy-cialis.ws",
"buy-computer-memory.net",
"buy-computer.us",
"buy-discount-airline-tickets.com",
"buy-laptop.biz",
"buy-rx-usa.com",
"buy-sex-toys.net",
"buycheapcialis",
"buycheappills.net",
"buyhgh",
"buylipitor",
"buyprilosec",
"buystuffpayless.com",
"buyzocor",
"byronbayinternet.com",
"c-start.net",
"ca-america.com",
"ca-s-ino.com",
"calendari-donne.com",
"calendari-donne.net",
"calendaridonne.com",
"calendaridonne.net",
"california-real-estate-sale.com",
"callingcardchoice.com",
"cambridgetherapynotebook.co.uk",
"camemberts.org",
"canadianlabels.net",
"cantwell2000.com",
"canzoni-italiane.com",
"canzoni-italiane.net",
"canzoni-italiane.org",
"canzoni-karaoke.com",
"canzoni-mp3.com",
"canzoni-mp3.us",
"canzoni-musica.com",
"canzoni.cc",
"canzonisanremo.com",
"canzonistraniere.com",
"capital-credit-cards.com",
"capquella.com",
"captain-stabbin-4u.com",
"captain-stabbin.blogspot.com",
"car-financing-low-rates.biz",
"car-fuck.net",
"car-rental-links.com",
"car-rental-search.com",
"car-rentals-2go.com",
"card-games-tfx.com",
"cardsloansmortgages.com",
"caribbean-poker-web.com",
"carnalhost.com",
"carnumbers.ru",
"cars-links.com",
"cartoni-animati.com",
"cartoni-hentai.com",
"cartoni-hentai.net",
"cartoni-hentai.org",
"cartoni-porno.com",
"cartonierotici.com",
"cartonigiapponesi.com",
"cartonihentai.net",
"cartopia.com",
"cas7.net",
"cash-advance-quick.com",
"cashadvanceclub.com",
"casino-bet-casino.com",
"casino-cash.net",
"casino-en-ligne.fr.vu",
"casino-game-trx.com",
"casino-games-4-us.com",
"casino-games-i.com",
"casino-gaming-trx.com",
"casino-in-linea.it.st",
"casino-jp.com",
"casino-on-net.com",
"casino-online-i.com",
"casino-online-on-line.com",
"casino-onnet-bonus.com",
"casino-slot.ws",
"casino-wins.net",
"casino.150m.com",
"casino.menegum.co.uk",
"casino747.net",
"casinochique.com",
"casinoequipmentsalesandrental.com",
"casinolasvegas-online.com",
"casinoplaces.net",
"casinos-8.com",
"casinos-jp.com",
"casinos-plus.com",
"castingagentur2004.de",
"catchathief.org",
"cbitech.com",
"ccie-ccnie.com",
"ccie130.com",
"ccna-ccna.com",
"ccna130.com",
"ccnp-ccnp.com",
"ccnp130.com",
"cds-xxl.de",
"cdshop-guenstig.de",
"celebrexonline.us",
"celebritylust.blog-city.com",
"celebritypics.ws",
"celebskin.com",
"celebtastic.com",
"cell-phone-accessories-dot.com",
"ceramics-store.com",
"certificationking.net",
"certified-new-autos.com",
"certified-new-cars.com",
"certified-new-suvs.com",
"certified-used-cars.com",
"certified-used-suvs.com",
"cesew.org",
"charisma.dyndns.dk",
"chat-l.de",
"chatten.bilder-j.de",
"chauffeurtours.co.uk",
"cheap-adult-sex-toys.com",
"cheap-airfare-airline-ticket.com",
"cheap-celebrex-prescriptions.com",
"cheap-christmas-gifts.co.uk",
"cheap-cigarettes.com",
"cheap-laptop-notebook.netdims.com",
"cheap-online-pharmacy.org",
"cheap-pills-online.com",
"cheap-web-hosting-companies.com",
"cheapacyclovir.com",
"cheapcodeine.biz",
"cheapdrugpharmacy.com",
"cheaper-digital-cameras.uk.com",
"cheaper-loans.eu.com",
"cheapest-pills-online.com",
"cheapgenericsoma.info",
"cheapsomaonline.biz",
"cheaptabs.envy.nu",
"checkmeds.com",
"cherrybrady.com",
"chickz.com",
"chillout.bpa.nu",
"chinaaircatering.com",
"chinagoldcoininc.com",
"chineseapesattack",
"chloesworld.com",
"choose-online-university.com",
"chrislaker.co.uk",
"christmas-casino.spb.ru",
"cialis-buy.com",
"cialis-dot.com",
"cialis-express.com",
"cialis-weekend-pills.com",
"cialis.homeip.net",
"cialisapcalis.com",
"cialisnetwork.com",
"cialisusa.bravehost.com",
"ciscochina.com",
"clamber.de",
"clanbov.com",
"classifiche-italiane.org",
"classifiche-musicali.com",
"classifiche-musicali.net",
"classifiche-musicali.org",
"classifichemusicali.com",
"claudiachristian.co.uk",
"claypokerchips-claypokerchips.com",
"cleanadulthost.com",
"cleannbright.co.uk",
"click-or-not.de",
"click-poker.com",
"clophillac.org.uk",
"closed-network.com",
"club-online-poker",
"club69.net",
"clubatlantiscasino.com",
"cmeontv.de",
"cnbjflower.com",
"cngangqiu.com",
"cntoplead.com",
"coed-girls.com",
"coffee-delivered.com",
"college-girl-pic.com",
"college-links.net",
"college-scholarships-grants.biz",
"combaltec.com",
"comeback.com",
"cometojapan.com",
"cometomalaysia.com",
"cometosingapore.com",
"cometothailand.com",
"completelycars.com",
"completelyherbal.com",
"comptershops-online.de",
"computer-onlinebestellung.de",
"computer-und-erotische-spiele-download.com",
"computerversand-xxl.de",
"condodream.com",
"condosee.com",
"conjuratia.com",
"consolidate-debt-usa.net",
"consolidation-loans.com",
"container-partner.de",
"cool-extreme.com",
"cool-mix.com",
"cool-poker.com",
"coolp.biz",
"coolp.net",
"coolp.org",
"coresleep.com",
"cosmeticsurgery.us",
"cosmeticsurgery.us.com",
"couponmountain.com",
"cover-your-feet.com",
"crazyfrog.wtf.la",
"creamfilledholes.biz",
"credit-cards-credit-cards-credit-cards.net",
"credit-factor.com",
"credit-links.net",
"credit-loans-2005.com",
"credit-report-links.net",
"creditcardpost.com",
"creditrepairsoft.com",
"creditsharpie.com",
"crepesuzette.com",
"crescentarian.net",
"crpublish.com",
"cum-facials.us",
"cumfiesta-4u.com",
"cumfietavideos.com",
"cumlogin.com",
"customer-reviews.org",
"cutpricepills.com",
"cyberfreehost.com",
"cycatki.com",
"cyclo-cross.co.uk",
"cykanax.com",
"dad-daughter-incest.com",
"daiiuvwx.com",
"dailyliving.info",
"dallmayr.de",
"damianer.top-100.pl",
"danni.com",
"darest.de",
"darkangelclan.com",
"darzgx.com",
"datestop.net",
"dating-choice.com",
"dating-harmony.com",
"dating-online-dating.org",
"dating-service-dating.com",
"dating-services-dating-service.com",
"dating999",
"dating999.com",
"davidtaylor.topcities.com",
"day4sex.com",
"debt-consolidation-i",
"debt-consolidation-i.biz",
"debt-consolidation-kick-a.com",
"debt-consolidation-low-rates.biz",
"debt-consolidation-now-online.com",
"debt-disappear.com",
"debt-help-bill-consolidation-elimination.com",
"debt-solution-tips.com",
"debtconsolidationfirm.net",
"debtconsolidationloans",
"debtconsolidationusa.org",
"debtmanagementcompanyonline.com",
"dedichepersonali.com",
"deep-ice.com",
"deikmann.de",
"dental-insurance-plan.freeservers.com",
"dental-plan-source",
"dentalinsurancehealth.com",
"department-storez.com",
"design4u.ws",
"desiraesworld.com",
"deutschlandweite-immobilienangebote.de",
"devilofnights.net",
"devilofnights.org",
"devon-daniels.com",
"devonanal.com",
"dia-host.com",
"dianepoppos.com",
"diarypeople.com",
"dick-deputy.com",
"diecastdot.com",
"diet-doctor.net",
"diet-pills-now",
"dieta-dimagrante.net",
"dieta-mediterranea.net",
"dieta-zona.com",
"dieta.cc",
"diete-dimagranti.com",
"diete.bz",
"diethost.net",
"dieting-review.com",
"dietpage.net",
"dietpatchformula.com",
"dietrest.com",
"diets-health.com",
"diets-plan.net",
"dietway.net",
"digital-projector.net",
"digitale-teile.de",
"digitaltwist.co.uk",
"direct-contact.com",
"direct-deals-for-you.info",
"direct-tv-for-free.com",
"direct-tv-online.com",
"directcarrental.com",
"directcti.com",
"directrape.com",
"directringtones.com",
"dirty-story.blogspot.com",
"discount-airfares-guide.com",
"discount-cheap-dental-insurance.com",
"discount-life-insurance.us",
"discountprinterrefill.com",
"discoveryofusa.com",
"dish-network-w.com",
"dish-network.org",
"disigncn.com",
"disney-hentai.org",
"divorce-links.com",
"dlctc.com",
"dnpose.com",
"dns110.com",
"dns2008.cn",
"dogfartmovieclips.com",
"dogfartmovieclips.com",
"dogolz.de",
"domkino.com.ua",
"donne-belle.net",
"donne-famose.biz",
"donne-muscolose.net",
"donne-muscolose.org",
"donne-nere.net",
"donne-nere.org",
"donne-nude.biz",
"donne-porche.com",
"donne-vogliose.com",
"donne.bz",
"donnebelle.net",
"donnefamose.biz",
"donnegrasse.org",
"donnemature.biz",
"donnemuscolose.com",
"donnenere.com",
"donnenere.net",
"donnenude.biz",
"donneporche.org",
"donnesexy.org",
"donnevogliose.net",
"donnevogliose.org",
"doo.pl",
"doobu.com",
"doorway-page-software",
"dostweb.com",
"dotcomup.com",
"downloadzipcode.com",
"dr.ag",
"dragonball-porno.com",
"dragonball-x.biz",
"dragonball-xxx.biz",
"dragonballporno.net",
"dragonballx.cc",
"dragonballxxx.biz",
"dressagehorseinternational.co.uk",
"drive-backup.com",
"drochka.com",
"drugsexperts.com",
"drugstore-online.us",
"drugstore.st",
"drunk-girls-flashing.com",
"drunk-girls-party.us",
"dunecliffesaunton.co.uk",
"dvd-copier.info",
"dvd-home-theatre.com",
"dvd-top-shop.info",
"dvd2.us",
"dwoq.com",
"dzwonki-polifoniczne-motorola.webpark.pl",
"e--pics.com",
"e-best-poker.com",
"e-bookszone.com",
"e-casino-bonus.com",
"e-cialis.net",
"e-credit-card-debt.com",
"e-debt-consolidation-loans.com",
"e-dental-insurance-plans",
"e-dental-plans.com",
"e-discus.com",
"e-fioricet.com",
"e-free-credit-reports.com",
"e-hoodia-gordonii.com",
"e-lemonlaw.com",
"e-news.host.sk",
"e-online-bingo.com",
"e-order-propecia.com",
"e-personalinjurylawyers",
"e-personalinjurylawyers.com",
"e-pills-buy.com",
"e-play-bingo.com",
"e-poker-games.info",
"e-southbeachdiet.com",
"e-top-pharmacy.com",
"e-tutor.com",
"e-virtual-casino.com",
"e40.nl",
"easy-application-credit-cards.com",
"easygo.hn.org",
"easyrecorder.com",
"easyseek.us",
"ebanking.info",
"ebaybusiness.net",
"ebloggy.com",
"ebony-girls.angelcities.com",
"ebony-xxx.us",
"ebookers.co.uk",
"ecblast.com",
"eccentrix.com/members/casinotips",
"echofourdesign.com",
"eclexion.net",
"ecologix.co.uk",
"eddiereva.com",
"edietplans.net",
"edmontgomeryministries.org",
"edpowerspasswords.com",
"edrugstore.md",
"education-line.com",
"edwardbaskett.com",
"effexor-web.com",
"effexor.cc",
"eggesfordhotel.co.uk",
"egygift.com",
"einfach-wunschgewicht.com",
"elcenter-s.ru",
"eldorado.com.ua",
"electricscooterland.com",
"electromark-uk.co.uk",
"electronics-info.com",
"elegant-candles.com",
"elektronikshop-xxl.de",
"elite-change.com",
"elitecities.com",
"emmasarah.com",
"emmss.com",
"enacre.net",
"enjoy-blackjack.com",
"enlargement-for-penis.com",
"envoyer-des-fleurs.com",
"eonsystems.com",
"epaycash.com",
"erbium12.com",
"erosway.com",
"erotic-free.com",
"erotic-lesbian-story.blogspot.com",
"erotic-video.us",
"erotic4free.net",
"erotische-geschichten-portal.com",
"escort-links.net",
"escorts-links.com",
"esesso-gratis.com",
"esmartdesign.com",
"ethixsouthwest.com",
"evananderson.topcities.com",
"evanstonpl.org",
"event-kalendarium.de",
"everyvoice.net",
"evromaster.ru",
"exclaim4creditcardprocessingmerchantaccount.com",
"exdrawings.com",
"exoticdvds.co.uk",
"exoticmoms.com",
"expoze.com",
"extrasms.de",
"extreme-rape.org",
"extreme-sex.org",
"f-z-a.com",
"f2g.net",
"f2s.be",
"fabida.net",
"fabulos.de",
"fabuloussextoys.com",
"facial-skin-care-center.com",
"family-incest-stories.com",
"family-incest.us",
"familydiet.org",
"famousppl.me.uk",
"fantasyfootballsportsbook.com",
"farm-beastiality.com",
"farmsx.com",
"fast-cash-quick-money-easy-loan.com",
"fast-fioricet.com",
"fast-mortgage-4-u.com",
"fasthost.tv",
"fat-cash.com",
"fat-lesbians.net",
"fat-pussy-sex.net",
"fateback.com",
"fatty-liver.cn",
"fatwarfare.com",
"favilon.net",
"fda.com.cn",
"fearcrow.com",
"federalgovernmentgrants.net",
"feidenfurniture.com",
"female-orgasms.org",
"fidelityfunding.net",
"fielit.de",
"figa.nu",
"film-porno.us",
"film456.com",
"filthserver.com",
"final-fantasy-hentai.org",
"finance-world.net",
"finanzen-marktplatz.de",
"find-cheap-dental-plans.com",
"find-lesbian-porn.com",
"find-u-that-mortgage.com",
"findbestpills",
"findbestpills.com",
"findbookmakers.com",
"finddatingsites.com",
"findsexxx.us",
"findyouruni.com",
"finger-bobs.com",
"fioricet-dot.com",
"fioricet-online-here.com",
"fioricet-web.com",
"fioricet.batcave.net",
"fioricet.bravehost.com",
"fioricet.st",
"fioricet4u",
"first-poker.com",
"first-time-story.blogspot.com",
"firstchoicebanksandpremiercredit.com",
"firsttimeaddition.com",
"fishoilmiracle.com",
"fitness-links.net",
"fitnessx.net",
"flafeber.com",
"flatbedshipping.com",
"fleshlight.org",
"fleshlight.ro",
"flexeril-web.com",
"flirt08.de",
"flowertobj.com",
"fly-sky.com",
"football--betting.net",
"football-betting-nfl.com",
"forceful.de",
"foreskin-restoration.net",
"forex-online-now.com",
"forex.inc.ru",
"forexintroducer.com",
"forlovedones.com",
"fortisenterprises.co.uk",
"foto-gay.us",
"foto-porno.us",
"foto-porno.ws",
"frangelicasplace.org",
"frankpictures.com",
"freak-view.com",
"freakycheats.com",
"free--online--poker",
"free--online-poker.com",
"free--online-poker.us",
"free-adult-chat-room.com",
"free-adult-check.com",
"free-blackjack-game.us",
"free-britney-spears-nude.biz",
"free-casino-games",
"free-casino-games-000",
"free-debt-consolidation-online.us",
"free-fast.net",
"free-games-links.com",
"free-gay-video-clip.com",
"free-hilton-paris-sex-video.com",
"free-horoscopes.biz",
"free-incest-stories-site.com",
"free-net-sex.com",
"free-online-poker",
"free-paris-nikki-hilton.blogspot.com",
"free-poker-download-i.com",
"free-poker-great-value.com",
"free-poker-rooms.us",
"free-satellite-tv-directv-nocable.com",
"free-satellite-tv-now.com",
"free-teens-galleries.com",
"free-texashold-em.us",
"free-texasholdem.us",
"free-traffic-generation.com",
"freeadult.de",
"freedvdplayer.cjb.net",
"freeeads.co.uk",
"freegovmoney.net",
"freegovmoney.us",
"freehostingpeople.com",
"freehustlersex.com",
"freeminimacs.com",
"freenetshopper.com",
"freenudegallery.org",
"freepicsdaily.com",
"freepornday.com",
"freeteenpicsandmovies.com",
"freeweb-hosting.com",
"freewebpage.org",
"freewebs.com",
"freewhileshopping.com",
"freshsexhosting.com",
"friko.pl",
"fsearch.dtdns.net",
"fuck-animals.com",
"full-access.net",
"fumetti-porno.org",
"fumettiporno.org",
"furrios.de",
"furry-kinks-looking.com",
"furry-kinks-looking.net",
"future-2000.net",
"g4h5.com",
"gaggingwhores.net",
"gaggingwhores.org",
"gagnerargent.com",
"gainmoresize.com",
"gals4all.com",
"galsonbed.com",
"gamble-on-football-online.com",
"gambleguru.net",
"gambling-a.us",
"gambling-card.ws",
"gambling-casinos-trx.com",
"gambling-homepage.com",
"games.cc",
"gamblingguidance.co.uk",
"gamefinder.de",
"games-advanced.de",
"gang-rape.org",
"gangbangbusgallery.com",
"gargzdai.net",
"garment-china.com",
"gartenshopper.de",
"garthfans.co.uk",
"gay-asian-porn.com",
"gay-b.com",
"gay-boy.us",
"gay-male-story.blogspot.com",
"gay-nude.us",
"gay-sex-videos.com",
"gay-twinks-sex.com",
"gay1ncest.com",
"gayfamilyincest.net",
"gayfunplaces.com",
"gays-porno-men-twinks-boys-sex.biz",
"gays-sex-gay-sex-gays.us",
"gayx.us",
"gb.com",
"gdgc.org",
"gelago.de",
"gem2.de",
"gemtienda.co.uk",
"generic-propecia.net",
"genimat.220v.org",
"genimat.cjb.net",
"geocities.com/alexgolddphumanrbriar",
"geocities.com/avbmaxtirodpaulmatt",
"geocities.com/brandtdleffmatthias7",
"geocities.com/cclibrannar_rover",
"geocities.com/constpolonskaalniko7",
"geocities.com/forestavmiagdust",
"geocities.com/free_satellite_tv_dish_system",
"geocities.com/gehentaiqrst",
"geocities.com/gematureqrst",
"geocities.com/gerapeqrst",
"geocities.com/ofconvbdemikqfolium",
"geocities.com/pashkabandtvcom",
"geocities.com/pautovalexasha_kagal",
"geocities.com/reutovoalexeypetrovseverin5",
"geocities.com/timryancompassmedius",
"gesundheit-total.com",
"gesundheitsshop-kosmetik.de",
"get-cell-phone-accessories.com",
"get-free-catalogs.com",
"get-freetrial.us",
"get-hardcore-sex.com",
"get-insurance-quotes.com",
"get-satellite-tv-dish.com",
"get-your-dish-tv.info",
"get-zoo.com",
"getaprescription.net",
"getdomainsandhosting.com",
"gethelp24x7.net",
"getmoregiveless.com",
"getrxscripts.biz",
"getstarted24x7.net",
"getyourlyrics.com",
"gfind.de",
"ghettoinc.com",
"giantipps.de",
"gifs-clipart-smiley.de",
"giochi-hentai.com",
"giochi-online.us",
"giochix.com",
"girls-get-crazy.org",
"girlshost.net",
"give-u-the-perfect-mortgage.com",
"giveramp.com",
"glendajackson.co.uk",
"global-verreisen.de",
"globalwebbrain.com",
"glory-vision.com",
"gloryhole-girls.angelcities.com",
"glucophagepharmacy.com",
"goapplyonline.com",
"godere.org",
"godwebdesign.com",
"gogito.com",
"gogof-ck.com",
"gojerk.com",
"goldpills.net",
"gomvents.com",
"gongi.pl",
"goodlife2000-geheimtipp.com",
"goodsexy.com",
"goodtv.cn",
"google163.net",
"google8.net",
"gorilka.atspace.com",
"gotooa.com",
"gotsw.net",
"gourmondo.de",
"govermentgrants.net",
"government--grant.com",
"government-federal-grants.com",
"government-grants.org",
"government-grants.ws",
"governmentalgrants.com",
"governmentfederalgrants.com",
"governmentgrants.tv",
"governmentgrants.ws",
"governmentgrantsresources.com",
"grannypictgp.com",
"grannysexthumbs.com",
"grants.biz",
"grantseekerpro",
"great-cialis.com",
"great-dish-tv-deals.info",
"greatnow.com",
"greecehotels-discount.com",
"green-tx.com",
"greenwood.ddns.ms",
"group-eurosex.com",
"growtech.cn",
"guardami.org",
"guenstige-krankenversicherung.com",
"guenstige-onlineshops.de",
"guenstige-sportartikel.de",
"guenstige-versicherungstarife.de",
"gunit.gotdns.com",
"guttermag.com",
"hair-loss-cure-x.com",
"hair-loss-cure.net",
"hairy-pussy-sex.net",
"hallo-tierfreund.de",
"hand-job.us",
"handjoblessons.org",
"handmade2000.co.uk",
"handsm.servehttp.com",
"handwerksartikel-xxl.de",
"handy-klingeltoene.eu.tp",
"handysprueche.de",
"handytone.us",
"hangchen.cn",
"hangchen.com",
"happy-shopping-online.com",
"happyagency.com",
"hard-sex-teen.com",
"hardcore-jpg.com",
"hardcore-junky.us",
"hardcore-pictures.us",
"hardcore-porn-links.com",
"hardcore-pussy.us",
"hardcore-sex.bz",
"hardcore-video.us",
"hardcorecash.net",
"hasslerenterprises.net",
"hasslerenterprises.org",
"hautesavoieimmobilier.com",
"hchcinc.com",
"hdic.net",
"hdic.org",
"headachetreatment.net",
"health-pills-online.com",
"health-pills.net",
"healthmore.net",
"healthrules.org",
"heartbeatofhealing.org",
"helpful-forum.com",
"helpful-pills-blog.com",
"hentai-anime.us",
"hentai-gratis.us",
"hentai-hard.com",
"hentai-porno.us",
"hentai-xxx.us",
"hentaigratis.net",
"hentaimanga.us",
"hentaiplayground.com",
"hentaix.net",
"hentaixxx.us",
"hentay.us",
"herbal-source.net",
"hermosa.us",
"herpies.net",
"heydo.com",
"hghadvisor.com",
"hghplanet.com",
"hgxweb.de",
"hi-finder.com",
"high-risk-merchant-account.org",
"highprofitclub.com",
"hilton-nicky-paris.blogspot.com",
"hion.cn",
"hit-logo-klingelton.com",
"hit-logo-ringetone.com",
"hit-logo-ringtone.com",
"hit-logo-suoneria.com",
"hit-melodias.com",
"hit-sonnerie.net",
"hit-sonneries.com",
"hits-logos-games.com",
"hits-logos-klingeltone.com",
"hitslogosgames.com",
"hlopci.w5.pl",
"hobbs-farm.com",
"hold-em-big.com",
"hold-pok.com",
"holdem-texaspoker.com",
"holding.errorworld.org",
"home-design.ws",
"home-equity-loans-mortgage-refinancing.com",
"home-loans-inc.com",
"home-style.ws",
"home-videos.net",
"home.pages.at",
"home.ro",
"homelivecams.com",
"homenetworkingsolutions.co.uk",
"hometeaminspection.net",
"hometeaminspection.org",
"hoodia--gardonii.com",
"hoodia.belleity.com",
"horny-honey.com",
"horny-world.com",
"hornymoms.net",
"hornypages.com",
"horoskop-auswertung.de",
"horse-racebetting.com",
"horse-racing--betting.net",
"horse-sex.ws",
"hostingplus.com",
"hostultra.com",
"hot-cialis.com",
"hot-escort-services.com",
"hot-mates.info",
"hot-naked-guys.net",
"hotel-bordeaux.cjb.net",
"hotelbookingserver.com",
"hotelsaficionado.com",
"hotelsplustours.com",
"hotfunsingles.com",
"hotsexys.com",
"hotusa.org",
"houseofsevengables.com",
"how-quit-smoking.com",
"how-to-play-poker-quick.com",
"hq-pictures.org",
"hs168.com",
"hswin.com",
"htmldiff.com",
"huazhangmba.com",
"humangrowthhormone.org",
"hunksandbabes.com",
"hustler.bz",
"hustlerbarelylegalteen.com",
"hustlerw.com",
"hxlll.net",
"hyper-sex.com",
"hypnobabies.co.uk",
"i--cialis.net",
"i-black-jack.com",
"i-butalbital-fioricet.com",
"i-buy-mortgage.com",
"i-directv.net",
"i-dish-network.org",
"i-flexeril.com",
"i-free-poker.com",
"i-horny.com",
"i-ink-cartridges.com",
"i-mortgage-online.com",
"i-online-bingo.com",
"i-online-poker.com",
"i-play-bingo.com",
"i-play-blackjack.com",
"i-play-casino.com",
"i-play-poker-online.biz",
"i-play-poker-online.com",
"i-play-poker-online.us",
"i-play-poker.com",
"i-skelaxin.com",
"i-soma.net",
"i-university-guide.com",
"i-wellbutrin.com",
"i-will-find-the-best-mortgage-lead.com",
"i-win-bingo.com",
"idebtconsolidation.org",
"idp4u.com",
"ifreepages.com",
"iipgoulkdfghj.com",
"illegalhome.com",
"illegalspace.com",
"im-naked.com",
"imagenes-tops.com.mx",
"imess.net",
"imitrex-web.com",
"immagini-hentai.org",
"immobilien-auswaehlen.de",
"immobilienangebote-auswahl.de",
"immobilienmakler-angebote.de",
"immobilienmakler-l.de",
"immobilienmarkt-grundstuecke.de",
"immobilierdessavoie.com",
"imobissimo.com",
"impotence-rx.biz",
"in-the-vip.org",
"inc-magazine.com",
"incest-movies-download.com",
"incest-photo.com",
"incest-photos-archive.com",
"incest-pics--incest.com",
"incest-pics-gallery.com",
"incest-reality.com",
"incest-relations.com",
"incest-stories-library.com",
"incest-stories.biz",
"incest-taboo.net",
"incest-videos-collection.com",
"inceststories.ws",
"incredishop.com",
"incsx.com",
"indian-sex-porno-movies-stories.com",
"indiasilk.biz",
"indiasilktradition.com",
"industrial-testing-equipment.com",
"industrialresource.biz",
"inescudna.com",
"inexpensiverx.net",
"infocenter-crm.com",
"inforceable.com",
"inforceables.com",
"ingyensms.net",
"ingyensms.org",
"innfg.de",
"insatiablepussy.com",
"inside.afraid.org",
"instant-quick-money-cash-advance-personal-loans-until-pay-day.com",
"instantsatellite.com",
"insurance-quotes-fast.com",
"insurancecompanies4you.com",
"insurancehere.net",
"int-fed-aromatherapy.co.uk",
"inter-ross.ru",
"international-candle-shop.com",
"international-cheese-shop.com",
"internet-meds.biz",
"internet-merchant-account-pro.com",
"internet-poker-online-4-u.com",
"internette-anbieter.de",
"interracial-sex.ws",
"inthevip-4u.com",
"inthevip-sex.com",
"intimplace.com",
"intymnie.com",
"inviare-mms.net",
"invio-mms.us",
"ipaddressworld.com",
"ipharmacy.com",
"ipmotor.com",
"ipsnihongo.org",
"ipupdater.com",
"irianjaya.co.uk",
"irs-us.net",
"isacommie.com",
"iservice.eu.com",
"isparkl.com",
"itgo.com",
"iul-online.de",
"iwebbroker.com",
"jack-x.com",
"jade.bilder-i.de",
"japan-partner.com",
"jenniferconnor.com",
"jewelry4navel.com",
"jfcadvocacy.net",
"jinlong.co.uk",
"jmsimonr.com",
"job-interview-questions-tips.com",
"jobsearchlegal.com",
"johnhowesatty.com",
"johnhuron.com",
"jokeria.de",
"jordanand.topcities.com",
"josephlied.com",
"judahskateboards.com",
"juega-al-casino.com",
"juliamiles.co.uk",
"jungfrauen-sex.com",
"junyuan.com.cn",
"justasex.com",
"jytouch.com",
"kantorg.h10.ru",
"kapsociety.org",
"kardtoons.co.uk",
"karibubaskets.com",
"karmicdebtconsolidation.com",
"kcufrecnac.com",
"keikoasura.com",
"keithandrew.co.uk",
"kewl-links.com",
"kewler.net",
"kinggimp.org",
"kinky-teen-videos.com",
"kinkyhosting.com",
"kiranthakrar.co.uk",
"kleinkinder-shop.de",
"klik-search.com",
"klingeltoene-handylogos.de.be",
"klingeltone-logo.com",
"klitoris.ca",
"kmsenergy.com",
"kohost.us",
"koihoo.com",
"kontaktanzeigen-bild.de.ms",
"kontaktlinsen-partner.de",
"kostenlose-sexkontakte.org",
"krantas.org",
"kraskidliavas.ru",
"kredit-ratenkredit-sofortkredit.de",
"kredite-online.de.ms",
"kredite-portal.de",
"kredite-sofortzusage.de",
"kreditkarten-sofort.de.ms",
"kupibuket.ru",
"kyed.com",
"kyfarmhouse.org",
"lablog.biz",
"lacetongue.com",
"lach-ab.de",
"lakesideartonline.com",
"lambethcouncil.com",
"landscape-painting.as.ro",
"langsrestaurant.com",
"lanreport.com",
"laptopy.biz.pl",
"las-vegas-real-estate-1.com",
"lastminute-blitz.de",
"lasvegas-real-estate.net",
"lasvegasrealtor.com",
"lasvegastourfinder.com",
"latina-hot-girls.com",
"latina-sex.ws",
"lavalifedating.com",
"leadbanx.com",
"learnhowtoplay.com",
"lebonpost.com",
"lechery-family.com",
"legalblonde.com",
"lesbian-girl.us",
"lesbian-sex-porn-pics-stories.com",
"lesbichex.com",
"lesbo-rama.com",
"leseratten-wunderland.de",
"letemgo.de",
"leveltendesign.com",
"lexapro-web.com",
"lexfinance.com",
"lgt-clan.ru",
"life-insurance-advisor.com",
"lifeinsurancefinders.com",
"likesmature.com",
"lingerie-land.com",
"link-dir.com",
"linkliste-geschenke.de",
"linseysworld.com",
"linuxwaves.net",
"lipitordiscount.biz",
"lipitordiscount.com",
"lir.dk",
"lisaber.com",
"list1st.com",
"listbanx.com",
"live-casino.com",
"livetexasholdem.com",
"livetexasholdem.com",
"livetexasholdem.com",
"livetexasholdem.com",
"livetreff.tv",
"livevents.de",
"lizardofoz.com",
"lizzie.dyndsl.com",
"lizziemills.com",
"loan-king.com",
"loan-superstore.com",
"loaninfotoday.com",
"loans-4all.com",
"loans-no-fax.com",
"loans.de.vu",
"locationcorse.free.fr",
"logo-beltonen.com",
"logo-free.com",
"logo-klingeltone.com",
"logo-max.com",
"logo-melodias.com",
"logo-mobiel.com",
"logo-mobile-repondeur.com",
"logo-moviles.com",
"logo-phones.com",
"logo-repondeur-mobile.com",
"logo-sonneries-sonnerie.com",
"logo-spiele.com",
"logo-tones.com",
"logod-helinad-mangud.com",
"logoer-mobil.com",
"logos-downloads.com",
"logos-free.com",
"logos-logos.be",
"logos-melodijas-speles.com",
"logos-mobile-repondeurs.com",
"logos-phones.com",
"logos-repondeurs-mobile.com",
"logos-sonneries-jeux.com",
"logos-sonneries-jeuxmobiles.com",
"logos-sonneries-sonnerie.com",
"logos-tone.com",
"logosik.pl",
"logotyper-mobil.com",
"lolika.net",
"longslabofjoy.com",
"lookforukhotels.com",
"loraxe.com",
"low-low-rates.com",
"lowclass.de",
"lowcost.us.com",
"lowest-rates-mortgages.com",
"lowinterestratecreditcards.net",
"luffassociates.co.uk",
"luxus-gourmetartikel.de",
"lvcpa.net",
"lvcpa.org",
"lvrealty.net",
"lynskey-admiration.org.uk",
"lyriclovers.com",
"macinstruct.net",
"mail333.com",
"mainentrypoint.com",
"mainjob.ru",
"majorapplewhite.info",
"male-enlargement.com",
"mallorycoatings.co.uk",
"maloylawn.com",
"mandysdiary.biz",
"mandysdiary.ws",
"manga-free.net",
"manga-free.org",
"manga-porn.us",
"manga-x.biz",
"manga-xxx.org",
"manufacturers-blog.com",
"march--madness.biz",
"march--madness.info",
"march--madness.org",
"marcomdeal.com",
"marshallsupersoft.com",
"marshallyachts.org",
"marteq-on.com",
"match-me-up.com",
"mature-big-tits.net",
"mature-old-mature.com",
"mature-sex-moms-porn.com",
"matureacts.com",
"maturefolk.com",
"maturetours.com",
"maxigenweb.com",
"mbgeezers.com",
"mcdortaklar.com",
"mcfimortgage.com",
"medcenterstore.com",
"mediaaustralia.com.au",
"mediavisor.com",
"medical4order.com",
"medications-4all.com",
"medicine-supply.com",
"medicinecheaper.com",
"medicinetrail.org",
"meds-pill.com",
"medweightloss",
"medyep.com",
"mega-spass.com",
"megapornstation.com",
"melincs.org",
"melodias-logos-juegos.com",
"members.fortunecity.com/kennetharmstrong",
"men-porn.us",
"men-sex.us",
"menexis.com",
"mengfuxiang.com",
"menguma.co.uk",
"menguma.com",
"mens-health-pills.com",
"menservers.com",
"menzyme.com",
"merditer.com",
"merseine.nu",
"mesothelioma-asbestos-help.com",
"mesothelioma-health.com",
"mesothelioma.net",
"metroshopperguide.com",
"mettle.com.cn",
"michigan-attorney.lbgo.com",
"micrasci.com",
"microsoft-com.us",
"middlecay.net",
"middlecay.org",
"midget-porn-sex.com",
"mietangebote-domain.de",
"migraine-relief.com",
"mikebunton.com",
"milesscaffolding.co.uk",
"milf-hardcore.net",
"milf-rider.us",
"milfporn.org",
"mingholee.com",
"misterwolf.net",
"mmorpg-headlines.com",
"mmsanimati.com",
"mneuron.com",
"mobile-repondeur-logo.com",
"mobile-repondeurs-logos.com",
"mobilefamilydental.com",
"mobilequicksale.com",
"mobilesandringtones.com",
"mode-domain.de",
"mode-einkaufsbummel.de",
"moltobene.ru",
"monavaletoys.com",
"money-cash-loans.com",
"money-room.com",
"moneybg.com",
"montaguefineart.com",
"mookyong.com",
"mor-lite.net",
"mor-lite.org",
"moris-dada.com",
"mortage-4all.com",
"mortgage-info-center.com",
"mortgage-rates-guide.net",
"mortgagemarketinginc.com",
"mortgagequestaz.com",
"mortgagerates4all.com",
"mortgages-links.net",
"mortloan.com",
"mostika.us",
"mother-son-incest-sex.net",
"motonet.pl",
"movies6.com",
"mp-forum.com",
"mp3download.bz",
"mp3x.biz",
"mpeg2pci.com",
"mrgoicoechea.com",
"mrn.vip.sina.com",
"mrpiercing.com",
"multipurpose-plants.net",
"multiservers.com",
"music-downloads-links.com",
"musica-da-scaricare.net",
"musica-gratis.biz",
"musica-gratis.org",
"musica-karaoke.net",
"musica-mp3.biz",
"musicamp3.us",
"musicbox1.com",
"musiccheap.us",
"musicenergy.com",
"muxa.ru",
"mxbearings.com",
"my-age.net",
"my-dating-agency.com",
"my-discount-cigarettes.com",
"my-sex-toys-store.com",
"myasiahotels.com",
"mybestcasinos.net",
"mybestclick.com",
"mycasinohome.com",
"mycheapcigstore.com",
"mycialispharmacy.com",
"mydatingagency.com",
"mydietdoctor.com",
"myeuropehotels.com",
"myfavlinks.de",
"mygenericrx.com",
"myrice.com",
"myrtlejones.com",
"myslimpatch.com",
"mystify2001.com",
"naar.be",
"nabmilor.com",
"nabmlior.com",
"nabpak.org",
"naked-gay.us",
"naked-pussy.us",
"naked-womens-wrestling-league-dvds.com",
"naked-womens-wrestling-league-videos.com",
"nakedboysfirsttime.com",
"nancyflowerswilson.com",
"narod.ru",
"nasty-pages.com",
"natel-mobiles.com",
"natural-barleygreen.com",
"natural-breasts-enhancement.net",
"naturalknockers.net",
"nehrucollege.org",
"neiladams.org.uk",
"net-mature.com",
"net-von-dir.de",
"netdims.com",
"netizen.org",
"netleih.de",
"netlogo.us",
"netsx.org",
"neurogenics.co.uk",
"new-cialis.com",
"neweighweb.net",
"neweighweb.org",
"newfurnishing.com",
"newgallery.co.uk",
"newmail.ru",
"newsnewsmedia.com",
"newtruths.com",
"newxwave.com",
"nfl-football-tickets.biz",
"nice-pussy.us",
"nicepages.biz",
"nicepages.net",
"nicepages.org",
"niceshemales.net",
"nichehit.com",
"nicolepeters.com",
"nieruchomosci.biz.pl",
"nifty-erotic-story-archive.blogspot.com",
"niibacca.afraid.org",
"nikkiwilliams.info",
"njhma.com",
"njunite.net",
"no-cavities.com",
"no-title.de",
"no1pics.com",
"nohassle-loans.com",
"noni-jungbrunnen.com",
"noni-top-chance.com",
"noni-vitalgetraenk.com",
"noniexpert.com",
"nonstop-casino.com",
"nonstopsex.org",
"noslip-picks.com",
"notsure.de",
"novacspacetravel.com",
"now-hiringsluts.com",
"nr-challenges.org",
"nude-black.us",
"nude-celebrity-dvd.com",
"nude-movies.us",
"nude-teens.name",
"nude-video.us",
"nudevol.us",
"nutritional-supplements.ws",
"nutritionalsupplementstoday.com",
"nutzu.com",
"nwwl-dvds.com",
"nwwl-videos.com",
"nylonex.com",
"nz.com.ua",
"odrducmibedfghj.com",
"officexl.de",
"officezl.com",
"officialdarajoy.com/wwwboard",
"officialdentalplan.com",
"officialsatellitetv.com",
"offseasonelves.com",
"ohamerica.org",
"okuk.org",
"old-sexy-sluts.com",
"olderr.4t.com",
"oldgrannyfucking.com",
"oliviagadamer.com",
"omega-fatty-acid.com",
"on-line-casino-deutsch.com",
"on-line-casinos-online.com",
"on-line-casinos-online.net",
"on-line-degree.org",
"on-line-kasino-de.com",
"on-pok.com",
"one-blackjack.com",
"one-cialis.com",
"one-debt-consolidation.com",
"one-poker-online.com",
"one-propecia.com",
"one-soma.com",
"onepiecex.net",
"oneseo.com",
"onexone.org",
"online-----poker",
"online--blackjack.info",
"online--pharmacy.us",
"online--sports-betting.com",
"online-auction-tricks.com",
"online-background-check.biz",
"online-black-jack-download.com",
"online-blackjack-online.com",
"online-buy-plavix.com",
"online-credit-report-online.com",
"online-dating-com.com",
"online-dating-singles-service.com",
"online-deals99.com",
"online-dot.com",
"online-escort-service.com",
"online-flexeril.com",
"online-gambling-123.biz",
"online-gambling-123.us",
"online-gambling-online.org",
"online-games-links.net",
"online-games24x7.com",
"online-games24x7.net",
"online-generics-store",
"online-job-source.com",
"online-medications24x7.com",
"online-pharmacy-24x7.net",
"online-pharmacy-online-pharmacies.com",
"online-pharmacy-order.com",
"online-photo-print.com",
"online-poker--tips.com",
"online-poker-200",
"online-poker-333.com",
"online-poker-555.com",
"online-poker-888",
"online-poker-a.com",
"online-poker-big.com",
"online-poker-bonus.us",
"online-poker-free.com",
"online-poker-guide.info",
"online-poker-kick-butt.com",
"online-poker-net.com",
"online-poker-online-poker",
"online-poker-special.com",
"online-poker-top-rated.com",
"online-prescription-pharmacy.com",
"online-prescription.st",
"online-prescriptions-internet-pharmacy.com",
"online-propecia-buyer.com",
"online-sports--betting",
"online-sports-betting-source",
"onlinedegreehq.com",
"onlinegamingassociation.com",
"onlinegamingassociation.com",
"onlinehgh.com",
"onlinepharmacy2004.net",
"onlinepoker-dot.com",
"onlinepoker-i.com",
"onlineshop.us.com",
"onlineslotsarcade.com",
"onlinesmoker.com",
"opensorcerer.org",
"operazione-trionfo.net",
"optimumpenis.com",
"oral-sex-cum.com",
"order-claritin.net",
"order-effexor.net",
"ordernaturals.com",
"orlandodominguez.com",
"orospu.us",
"otito.com",
"ottawavalleyag.org",
"our-planet.org",
"ourhealthylife.net",
"ourtownhelps.org",
"outoff.de",
"overseaspharmacy.com",
"ovulation-kit.com",
"owns1.com",
"ownsthis.com",
"p-reise.de",
"p5.org.uk",
"p6.org.uk",
"p7.org.uk",
"p8.org.uk",
"p9.org.uk",
"pacific-poker-top-place.com",
"pages4people.com",
"pagetwo.org",
"pai-gow-keno.com",
"painkillersonline.biz",
"paisleydevelopmentassociation.org",
"pamperedchef-online.com",
"paololinks.porkyhost.com",
"paperscn.com",
"paramountseedfarms.net",
"paramountseedfarms.org",
"paris-and-nicky-hilton-pictures.blogspot.com",
"paris-hilton-video-blog.com",
"paris-hilton-videos.biz",
"paris-movie-hilton.blogspot.com",
"paris-naked-hilton.blogspot.com",
"paris-nicky-hilton.blogspot.com",
"paris-nikki-hilton.blogspot.com",
"parkviewsoccer.net",
"parkviewsoccer.org",
"partnersmanager.com",
"partnersuche-partnervermittlung.com",
"party-poker-e.com",
"party-poker-leading-site.com",
"party-poker-ltd.com",
"party-poker-player.com",
"party-poker-x",
"partybingo.com",
"partypoker-i",
"partypoker-i.us",
"partypoker.com",
"partypokeronline.org",
"passende-klamotten.de",
"passwordspussynudity.com",
"pastramisandwich.us",
"pasuquinio.com",
"payday-cash-loans",
"payday-loan",
"payday-loan-payday.com",
"paydayl0an.com",
"paylesspaydayloans.com",
"payment-processing.com",
"paysites.info",
"pc-choices.com",
"pcdweb.com",
"pedronetwork.com",
"pedronetwork.com",
"peepissing.com",
"penelopeschenk.com",
"penilestretch.com",
"penis-enlargment.net",
"penisimprovement.com",
"penisresearch.com",
"perfect-dedicated-server.com",
"perfect-mortgage-lead-4-u.com",
"perkyoneplace.com",
"personal-finance-tips.com",
"personal-injuries-law.com",
"personal-injury-lawyer.us.com",
"personalads.us.com",
"personales.com",
"personals-online-personals.com",
"personalserotic.com",
"petlesbians.com",
"petroglyphx.com",
"phantadu.de",
"pharmaceicall.com",
"pharmacy-links.net",
"pharmacy2003.com",
"pharmacyprices.net",
"philippestarckwatches.co.uk",
"phone-cards-globe.pushline.com",
"phono.co.il",
"photobloggy.buzznet.com",
"php5.sk",
"phrensy.org",
"picnic-basket.more.at",
"pics--movies.com",
"pics-db.com",
"pics-porn.org",
"pics-stories.com",
"pics-videos.net",
"picsfreesex.com",
"picsteens.com",
"pictures-and-videos.com",
"pictures-archive.com",
"pictures-movies.net",
"pictures-movies.org",
"pictures6.com",
"piercing-auswaehlen.de",
"piercing-magic.com",
"piercingx.com",
"piggi.descom.es",
"pill-buy.com",
"pillblue.com",
"pillchart.com",
"pillexchange.net",
"pillfever.com",
"pillgrowth.com",
"pillhub.com",
"pillhunt.com",
"pillinc.com",
"pillmarket.net",
"pills-for-penis.com",
"pillsbestbuy.com",
"pillsdomain.com",
"pillsking.com",
"pillslim.com",
"pillsupplier.com",
"pilltip.com",
"pimpcasino.com",
"pimphos.com",
"pimpspace.com",
"pinkzoo.com",
"piranho.com",
"pisangrebus.com",
"pj-city.com",
"planetluck.com",
"plasticmachinery.net.cn",
"play-7-card-stud-poker.com",
"play-7-card-stud-poker.us",
"play-cash-bingo-online.com",
"play-online-poker-z.com",
"play-partypoker.us",
"play-poker-i.com",
"play-poker-onlie-kick-ass.com",
"play-poker-online-z.com",
"play.eu.com",
"playandwin777.com",
"playandwinit777.net",
"player-tech.com",
"playgay.biz",
"playmydvd.com",
"playnowpoker.com",
"playweb.blogspot.com",
"plygms.de",
"pocketsound.org",
"pok7.com",
"pokemon-hentai.com",
"pokemon-hentai.org",
"pokemonhentai.net",
"pokemonx.biz",
"poker-8.com",
"poker-888-e.com",
"poker-e-win.com",
"poker-e-wins.com",
"poker-games-bonus.com",
"poker-games-top-ranked.com",
"poker-games.cjb.net",
"poker-hands-secrets.com",
"poker-homepage.com",
"poker-magic.org",
"poker-me-up.com",
"poker-on-web.com",
"poker-online-anytime.com",
"poker-rooms-777",
"poker-rooms-777.com",
"poker-rules-easy-4u.com",
"poker-tables-best-deals.com",
"poker-w.com",
"poker-wsop-2005.com",
"poker777game",
"poker79.com",
"pokerorg.net",
"pokerpage.biz",
"pokerpartnership.com",
"pokerqu.com",
"pokerweb.be",
"polifoniczne.org",
"polyphone.us",
"pompini.nu",
"popwow.com",
"porevo.lookin.at",
"porn-4u.net",
"porn-dvds-dot.com",
"porn-house.us",
"porn-sites-list.com",
"porn-stars.org",
"porn-stud-search.org",
"pornevalution.com",
"porngrub.com",
"pornlane.com",
"porno-v.com",
"pornogratis.bz",
"pornosexbest.com",
"pornostars.cc",
"pornovideos-versand.com",
"pornstar4all.com",
"pornwww.com",
"poster-shop.us",
"postersshop.us",
"power-rico.de",
"pregnant-sex-free.us",
"prepaylegalinsurance.com",
"prescription-drugs.st",
"prescriptions.md",
"preteen-models.biz",
"preteen-sex.info",
"preteen-young.net",
"prettypiste.com",
"princeofprussia.org",
"printerinkseller.com",
"prism-lupus.org",
"privacy-online.biz",
"private-krankenversicherung-uebersicht.com",
"private-network.net",
"privatediet.com",
"pro-collegefootballbetting.com",
"pro-rolex-replica-watches",
"pro-rolex-replica-watches.com",
"product-paradise.com",
"projector-me.com",
"prom-prepared.com",
"promindandbody.com",
"propecia-depot.com",
"propecia-for-hair-loss.com",
"propecia-for-hair-loss.net",
"propecia-info.net",
"propecia-store.com",
"propecia.bravehost.com",
"propeciaonline.biz",
"propeciapower.com",
"prosearchs.com",
"pryporn.com",
"pseudobreccia60.tripod.com.ve",
"psites.biz",
"psites.net",
"psites.org",
"psites.us",
"psxtreme.com",
"psychexams.net",
"psychexams.org",
"punksongslyrics.com",
"puppyduk.com",
"pureteenz.com",
"pushline.com",
"pussy-cum.us",
"pussy-d.com",
"pussy-movies.us",
"qinsi.com",
"qqba.com",
"quangoweb.com",
"quick-drugs.biz",
"quick-drugs.com",
"quickdomainnameregistration.com",
"quickie-quotes.com",
"r-300.com",
"r-3100.com",
"r-400.com",
"r-4100.com",
"r00m.com",
"racconti-gay.org",
"radsport-artikel.de",
"raf-ranking.com",
"ragazze.bz",
"rampantrabbitvibrator.co.uk",
"randyblue.info",
"randysrealtyreview.com",
"rape--stories",
"rape-fantasy-pics.com",
"rape-stories.biz",
"rapestoriespics",
"rapid-merchant-account.com",
"rapid.myserver.org",
"ratenkredit-center.de",
"ratenkredit-shop.de",
"raw-pussy.us",
"rbfanz.com",
"real-online-poker",
"real-sex.us",
"realestateslaws.com",
"realisticforeignpolicy.org",
"reality-xxx.biz",
"reallyhot.org",
"realmilfgangbang.biz",
"realtickling.com",
"rebjorn.co.uk",
"redcentre.org",
"redi.tk",
"refinance-mortgage-home-equity-loan.com",
"reggaeboyzfanz.com",
"registerxonline.com",
"registrarprice.com",
"reglament-np.ru",
"reisen-domain.de",
"relievepain.org",
"rent-games-movies.com",
"rental-2004.com",
"rentalcarsplus.com",
"repair-restore-bad-credit-report-identity-theft.com",
"repaircreditonline.net",
"repondeurs-logos-mobile.com",
"republika.pl",
"reservedining.net",
"reservedining.org",
"restaurant-l.de",
"rethyassociates.net",
"rethyassociates.org",
"reviewonlinedating.com",
"rhinoslinks.com",
"rhinosthumbs.com",
"ricettegolose.com",
"richshemales.com",
"rifp.org",
"rightdebt.com",
"ringsignaler-ikon-spel.com",
"ringtone-logo-game.com",
"ringtoner-logoer-spill.com",
"ringtonespy.com",
"rittenhouse.ca",
"rmg.com.cn",
"robinson-entertainment.com",
"robosapiensource",
"robosapiensource.com",
"roboticmilking.com",
"romane-buecher.de",
"romeo-ent.com",
"ronnieazza.com",
"rossmann.de",
"roulette---online.com",
"roulette-w.com",
"royaladult.com",
"royalfreehost.com/teen/amymiller",
"royalmailhotel.com",
"ru21.to",
"ruitai88.com",
"rulo.biz",
"rx-central.net",
"rx-lexapro.biz",
"rx-pills-r.us",
"rx-store.com",
"rxpainrelief.net",
"rxpills.biz",
"rxweightloss.org",
"rydoncycles.co.uk",
"s-fuck.com",
"s-sites.net",
"safecreditonline.com",
"sailor-moon-hentai.org",
"sailor-moon-hentai.us",
"salcia.co.uk",
"salute-bellezza.net",
"salute-bellezza.org",
"salute-benessere.org",
"salute-e-benessere.net",
"salute-igiene.com",
"salute-malattie.com",
"salute-malattie.net",
"samiuls.com",
"sandhillaudio.com",
"sandrabre.de",
"sapphicerotica.biz",
"sarennasworld.com",
"sat-direct.net",
"satellite-direct-for-you.com",
"satellite-network-tv.com",
"satellite-tv.cjb.net",
"satellite.bravehost.com",
"satellitetv-reviewed.tripod.com",
"satellitetvboutique.com",
"saveondentalplans.com",
"saveonpills.net",
"sbdforum.com",
"sbt-scooter.com",
"sc10.net",
"scarica-mp3.biz",
"scarica-mp3.com",
"scarica-musica-mp3.org",
"scarica-musica.com",
"scarica-musica.org",
"scaricamp3.us",
"scaricare-canzoni.com",
"scaricare-canzoni.net",
"scaricare-canzoni.org",
"scaricare-mp3.org",
"scatporn.info",
"scent-shopper.com",
"schanee.de",
"schmuck-domain.de",
"scottneiss.net",
"se-traf.com",
"se24h.com",
"search-1.info",
"search-engine-optimization-4-us.com",
"search-milf.com",
"search722.com",
"searchinsurance.net",
"searchtypo.com",
"secureroot.org",
"security-result.com",
"sedonaretreat.org",
"seekartist.com",
"seeker-milf.com",
"seitensprung-gratis.com",
"selectedsex.com",
"selena-u.ru",
"selten-angeklickt.de",
"semax14.info",
"semax15.info",
"semax16.info",
"sempo-tahoe.com",
"senior.mine.nu",
"seoy.com",
"servepics.com",
"servicesdating.net",
"sesso-gratis.cc",
"sesso-online.net",
"sessoanalex.com",
"sessox.biz",
"seven-card-stud.biz",
"seven-card-stud.us",
"sewilla.de",
"sex-4you.org",
"sex-bondagenet.org",
"sex-friend.info",
"sex-livecam-erotik.net",
"sex-lover.org",
"sex-manga.us",
"sex-mates.info",
"sex-photos.org",
"sex-pic-sex.com",
"sex-pussy.us",
"sex-toys-next-day.com",
"sex4dollar.com",
"sexadultdating.com",
"sexbrides.com",
"sexchat.ccx",
"sexcia.com",
"sexe.vc",
"sexglory.com",
"sexiestserver.com",
"sexingitup.com",
"sexmuch.com",
"sexo9.com",
"sexplanets.com",
"sexschlucht.de",
"sexshop-sexeshop.com",
"sexshop.tk",
"sextoysportal.com",
"sextoyssexvideos.com",
"sexual-shemales.com",
"sexual-story.blogspot.com",
"sexushost.com",
"sexvoyager.com",
"sexwebclub.com",
"sexwebsites.com",
"sexy-ass.us",
"sexy-babes.us",
"sexy-celebrity-photos.com",
"sexy-girls.org",
"sexy-lesbian.us",
"sexy-pussy.us",
"sexynudea.com",
"sfondi--gratis.com",
"sfondi-desktop-gratis.com",
"shadowbaneguides.net",
"shannon-e.co.uk",
"shareint-store.com",
"shemale-cum-tgp.com",
"shemale-girls.com",
"shemalesex.biz",
"shemalesland.com",
"shemalezhost.com",
"shemalki.com",
"shfx-bj.com",
"shhilight.com",
"shirts-t-shirts.com",
"shop-opyt.com",
"shop.tc",
"shop24x7.net",
"shopping-liste.de",
"shoppingideen-xxl.de",
"shoppyix.com",
"showsontv.com",
"sicarrow.co.uk",
"silky-smooth-pussy.com",
"simon-scans.com",
"simple-pharmacy.com",
"simplemeds.com",
"simpsonowen.co.uk",
"sindyhalliday.com",
"sinfree.net",
"site-mortgage.com",
"sitesarchive.com",
"siti-porno.us",
"ski-resorts-guide.com",
"skidman.com",
"slatersdvds.co.uk",
"slng.de",
"slot-machines-slots.com",
"slotmachinesguide.net",
"slots-8.com",
"slots-w.com",
"slotsjockey.com",
"slowdownrelax.com",
"slut-wife-story.blogspot.com",
"slutcities.com",
"small-business-grants.biz",
"smallbusinessgrants.biz",
"smart-debt-consolidation-and-credit-services.com",
"smartdot.com",
"smartonlineshop.com",
"smerfy.pl",
"sms-sms-sms.org",
"sms-sprueche-4fun.de",
"sms-sprueche.com",
"sms.pl",
"smutwebsites.com",
"sneakysleuth.com",
"socoplan.org",
"sofort-mitgewinnen.de",
"sofortkredit-tipps.de",
"soft-industry.com",
"soft.center.prv.pl",
"software-einkaufsmarkt.de",
"software-linkliste.de",
"software-review-center.org",
"software.thedir.net",
"softwaredevelopmentindia.com",
"soittoaanet-logot-peli.com",
"sol-web.de",
"soma-cheap-soma.com",
"soma-solution.com",
"soma-web.com",
"soma.st",
"somacheap",
"somaspot.com",
"sommerreisen-2004.de",
"sonderpreis.de.com",
"sonnerie-compositeur.com",
"sonnerie-hifi-sms.com",
"sonnerie-logo-jeu.com",
"sonnerie-logo-sonneries.com",
"sonnerie-logos-sonneries.com",
"sonnerie-logos.be",
"sonnerie-max.com",
"sonnerie-portable-composer.com",
"sonnerie-portable.be",
"sonnerie-sonneries-logo.com",
"sonnerie-sonneries-logos.com",
"sonnerie-sonneries.net",
"sonnerie.net",
"sonneries-gsm-sms.com",
"sonneries-sonnerie-logo.com",
"sonneries-sonnerie-logos.com",
"sonneries.fr",
"sorglos-kredit.de",
"soulfulstencils.com",
"southbeachdiet.us.com",
"southbeachdietrecipe.biz",
"spacige-domains.de",
"spannende-spiele.de",
"spassmaker.de",
"speedsurf.to",
"speedy-insurance-quotes.com",
"spermincreasingpills.com",
"spiele-kostenlose.com",
"spiele-planet.com",
"spoodles.com",
"sportartikel-auswahl.de",
"sportecdigital.com",
"sportingcolors.org",
"sportlich-chic.de",
"sports---betting.com",
"sports-betting-",
"sports-betting-a.com",
"sports-inter-action.com",
"sportsbettingexpert.com",
"sportsorg.biz",
"sportsparent.com",
"spp-net.de",
"spy-patrol.com",
"spyshots.bpa.nu",
"spyware-links.com",
"staffordshires.net",
"staplethis.de",
"starpills.com",
"statusforsale.de",
"steelstockholder.co.uk",
"stellenangebote-checken.de",
"stellenangebote-l.de",
"stevespoliceequipment.com",
"stfc-isc.org",
"sting.cc",
"stmaryonline.org",
"stock-power.com",
"stolb.net",
"stop-depression.com",
"stop-snoring.crpublish.com",
"stopp-hier.de",
"stopthatfilthyhabit.com",
"stories--archive.com",
"stories-adult.net",
"stories-inc.com",
"stories-on-cd.net",
"stories-on-cd.org",
"storiespics",
"storiespics.game-host.org",
"storiespics.game-server.cc",
"storiespics.gotdns.com",
"storiespics.gotdns.org",
"storiespics.ham-radio-op.net",
"storiespics.homedns.org",
"storiespics.homeftp.net",
"storiespics.homeftp.org",
"storiespics.homeip.net",
"storiespics.homelinux.com",
"storiespics.homelinux.net",
"storiespics.homelinux.org",
"storiespics.homeunix.com",
"storiespics.homeunix.net",
"storiespics.homeunix.org",
"striemline.de",
"stripclubexposed.info",
"strivectinsd.com",
"stunningsextoys.com",
"styrax-benzoin.com",
"success-biz-replica.com",
"suma-eintragen.de",
"sumaeintrag-xxl.de",
"sunbandits.com",
"sunnyby.com",
"suonerie-center.com",
"suonerie-download.com",
"suonerie-loghi-gratis.com",
"suonerieloghix.com",
"suoneriex.net",
"suoyan.com",
"super-bowl-bet.biz",
"super-celebs.com",
"super-cialis.com",
"superbowl--betting.com",
"superdolphins.org",
"superpornlist.com",
"surfe-und-staune.de",
"susiewildin.com",
"sutra-sex.com",
"suttonjames.net",
"suttonjames.org",
"svitonline.com",
"swedenet.com",
"swedenetwork.com",
"sweet-horny.com",
"sweetbuyz.com",
"sweethotgirls.com",
"sweetteenbodies.com",
"swinger-story.blogspot.com",
"swingersadult.net",
"swingersunidos.com",
"sydney-harbour.info",
"sylphiel.org",
"sylviapanda.com",
"sysaud.com",
"t35.com",
"t3n.org",
"tabsinc.com",
"take-credit-cards.com",
"taliesinfellows.org",
"talktobabes.com",
"tanganyikan-cichlids.co.uk",
"tapbuster.co.uk",
"taremociecall.com",
"targetindustries.net",
"targetingpain.net",
"tattoo-entwuerfe.de",
"tatuaggi-gratis.com",
"tatuaggi-piercing.org",
"tatuaggi-tribali.com",
"tatuaggi.cc",
"tatuaggi.us",
"tatuaggitribali.com",
"tclighting.net",
"tclighting.org",
"tdk-n.com",
"teambeck.org",
"teamregules.com",
"tecrep-inc.net",
"tecrep-inc.org",
"teddbot.com",
"teddnetwork.com",
"teen-babes.us",
"teen-boys-fuck-paysite.com",
"teen-d.com",
"teen-hentai.us",
"teen-movie.us",
"teen-porn-movie.net",
"teen-sex-porn-models.com",
"teen-video.us",
"teen-xxx.us",
"teenagerzone.com",
"teenbrazil.info",
"teenbrazil.ws",
"teens.wox.org",
"teensluts.org",
"teentopanga.name",
"teenxxxpix.net",
"telechargement-logiciel.com",
"terminator-sales.com",
"terra.es/personal2/dee7boquo",
"terra.es/personal2/markus69",
"testi-canzoni.com",
"testi-canzoni.net",
"testi-musicali.com",
"testi-musicali.net",
"testi.cc",
"tests-shop.com",
"tette.bz",
"tettone.cc",
"texas--hold--em",
"texas--hold-em",
"texas--holdem",
"texas-hold-em",
"texas-holdem",
"texas-poker",
"texasproptax.com",
"tgplist.us",
"thatwhichis.com",
"the-boys-first-time.net",
"the-boysfirsttime.com",
"the-date.com",
"the-first-time-auditions",
"the-hun-site.com",
"the-hun-yellow-page-tgp.com",
"the-pill-bottle.com",
"the-proxy.com",
"the1930shome.co.uk",
"thebans.com",
"theblackfoxes.com",
"theceleb.com",
"thecraftersgallery.com",
"thefreecellphone.com",
"thehadhams.net",
"themadpiper.net",
"thepornhost.com",
"thepurplepitch.com",
"therosygarden.com",
"thesoftwaregarage.co.uk",
"thespecialweb.com",
"thewebbrains.com",
"thorcarlson.com",
"thumbscape.com",
"ticket-marktplatz.de",
"tickets4events.de",
"tiere-futter.de",
"tiffany-towers.com",
"tigerspice.com",
"tikattack.com",
"timescooter.com",
"tina4re.com",
"tips-1a.de",
"tits-center.com",
"tits-cumshots.net",
"tm258.com",
"tmsathai.org",
"tofik.pl",
"tokyojoes.info",
"tonos-celulares.com.mx",
"tonos-nokia.com.mx",
"top-blackjack-game",
"top-blackjack.net",
"top-casinos-net.com",
"top-cialis.com",
"top-deals-online-pharmacy",
"top-deals-pills",
"top-deals-pills.info",
"top-dedicated-servers.com",
"top-des-rencontres.com",
"top-fioricet.com",
"top-internet-blackjack.com",
"top-milf.com",
"top-of-best.de",
"top-online-poker-bonuses",
"top-online-slots.com",
"top-pharmacy.net",
"top-poker-21.com",
"top-sex-base.com",
"top-skelaxin.com",
"top-soma.com",
"top-the-best.de",
"top-video-poker.info",
"top-wins-2005.com",
"topaktuelle-tattos.de",
"topcialis.com",
"topmeds.net",
"toques-logos-jogos.com",
"toshain.com",
"total-verspielt.de",
"totallyfreecreditreport.org",
"touchwoodmagazine.org.uk",
"tournamentpoker.biz",
"training-one.co.uk",
"trannies.angelcities.com",
"tranny-pic-free.com",
"tranny-sex-clips.com",
"tranny.150m.com",
"trannys.blowsearch.ws",
"trannysexmovie.com",
"transbestporn.com",
"transestore.com",
"transpire.de",
"traum-pcs.de",
"treocat.com",
"triadindustries.co.uk",
"trixieteen.org",
"troggen.de",
"troie.bz",
"trolliges.de",
"trucchi-giochi.us",
"trueuninstall.com",
"trumpetmission.org",
"tt33tt.com",
"tt7.org",
"tubegator.com",
"tuff-enuff.fnpsites.com",
"turist.com.pl",
"tvforum.org",
"twinky.org",
"tygef.org",
"u-w-m.ru",
"uaeecommerce.com",
"ufosearch.net",
"uk-virtual-office-solutions.com",
"uk.net",
"ukrainewife.net",
"ultra-shop.info",
"ultracet-web.com",
"ultrampharmacy.com",
"unbeatablecellphones.com",
"unbeatablemobiles.co.uk",
"unbeatablerx.com",
"unccd.ch",
"underage-pussy.net",
"undonet.com",
"uni-card.ru",
"united-cash.com",
"unitedarchive.com",
"unrisd.com",
"unscramble.de",
"unterm-rock.us",
"upsms.de",
"urlaubssonne-tanken.de",
"us-cash.com",
"us-meds.com",
"usa-birthday-flowers.com",
"usa-car-insurance.com",
"usa-car-loans.com",
"usa-cash-advance.com",
"usa-escorts-123.com",
"usbitches.com",
"uscashloan.com",
"usedcarsforsale",
"v27.net",
"v29.net",
"v3.be",
"vacation-rentals-guide.com",
"valeofglamorganconservatives.org",
"vcialis.com",
"venera-agency.com",
"veranstaltungs-tickets.de",
"vergleich-versicherungsangebote.de",
"versicherungsangebote-vergleichen.de",
"versicherungsvergleiche-xxl.de",
"versteigerungs-festival.de",
"verybrowse.com",
"verycd.com",
"verycheapdentalinsurance.com",
"viaggix.com",
"viapaxton.com",
"video-n.com",
"video-poker",
"video-poker-dot.com",
"video-poker-world.net",
"video-porno.nu",
"videohentai.org",
"videoportfolios.com",
"vilentium.de",
"villagesx.com",
"vimax.lx.ro",
"vimax.topcities.com",
"vip-condom.com",
"vip-online-pharmacy.com",
"vitamins-for-each.com",
"vivalatinmag.com",
"vivlart.com",
"vixensisland.com",
"vladgorlum.gotdns.com",
"vladstepanov.brunst.dk",
"vod-solutions.com",
"voiphone.cn",
"vonormytexas.us",
"vpmt.com",
"vpshs.com",
"vrajitor.com",
"vtsae.org",
"w-ebony.com",
"w5.pl",
"wake.rlights.com",
"waldner-msa.co.uk",
"wancheng.cn",
"warblog.net",
"washere.de",
"watches-sales.com",
"waterbeds-dot.com",
"wayshell.co.uk",
"wblogs.com",
"wcgaaa.org",
"we-live-together-4u.com",
"weareconfused.org.uk",
"wearethechampions.com",
"web-aks.com",
"web-cam-101.com",
"web-cam-porn.net",
"web-cialis.com",
"web-revenue.com",
"webanfragen.de",
"webblogs.biz",
"webcam-erotiche.com",
"webcenter.pl",
"webcindario.com",
"webcopywizard.net",
"webhgh.com",
"webpark.pl",
"webrank.cn",
"websitedesigningpromotion.com",
"weddings-info.com",
"weddings-links.com",
"weekend-cialis",
"weighlessrx.com",
"weight-loss-central.org",
"weight-loss-links.net",
"weightlossplace.net",
"weitere-stellenangebote.de",
"wellness-getraenk.de",
"wet-4all.com",
"wet-pantie.net",
"wet-pussy.us",
"wethorny.com",
"whackingpud.com",
"white-shadow-nasty-story.blogspot.com",
"whitehouse.com",
"whizzkidsuk.co.uk",
"wholesalepocketbike.com",
"wild-porno-girls.com",
"willcommen.de",
"win-in-poker.com",
"wincmd.ru",
"wincrestal.com",
"windcomesdown.com",
"wirenorth.com",
"wiset-online.com",
"wisskie.cx",
"witch-watch.com",
"witz-net.de",
"wizardsoul.com",
"woodyracing.co.uk",
"workfromhome-homebasedbusiness.com",
"world-candle.com",
"world-cheese.com",
"world-series-of-poker-1996.com",
"worldmusic.com",
"worldsexi.com",
"worldwide-deals.net",
"worldwide-games.net",
"worldwide-holdem.com",
"worldwide-online-pharmacy.net",
"worldwide-sources.com",
"worldwidecasinosearch.com",
"wotcher.de",
"www-sesso",
"www-webspace.de",
"x-baccarat.com",
"x-baccarat.us",
"x-beat.com",
"x-bingo.com",
"x-craps.com",
"x-craps.us",
"x-fioricet.com",
"x-free-casino-games.com",
"x-internet-casino.com",
"x-jack.us",
"x-pictures.net",
"x-pictures.org",
"x-ring-tones.com",
"x-ringtones.com",
"x-roulette.com",
"x-roulette.us",
"x-roullete.com",
"x-slots.com",
"x-slots.us",
"x-stories.org",
"x-video-poker.com",
"x-video-poker.us",
"xadulthosting.com",
"xadultpersonals.com",
"xaper.com",
"xdolar.com",
"xfreehosting.com",
"xgsm.org",
"xgsmhlhc.com",
"xin-web.de",
"xingzhiye.com",
"xlboobs.net",
"xmilf.us",
"xmix.net",
"xnxxx.com",
"xpictx.com",
"xprescription.com",
"xprv.com",
"xrated-midgets.com",
"xratedcities.com",
"xsesso.biz",
"xxshopadult.com",
"xxuz.com",
"xxx-alt-sex-story.blogspot.com",
"xxx-database.com",
"xxx-dvd.biz",
"xxx-erotic-sex-story.blogspot.com",
"xxx-first-time-sex-story.blogspot.com",
"xxx-free-erotic-sex-story.blogspot.com",
"xxx-gay-sex-story.blogspot.com",
"xxx-girls-sex.com",
"xxx-password-web.com",
"xxx-pussy.us",
"xxx-sex-movies.org",
"xxx-sex-story-post.blogspot.com",
"xxx-spanking-story.blogspot.com",
"xxx-stories.net",
"xxx-story.blogspot.com",
"xxxchan.com",
"xxxseeker.com",
"xxxwashington.com",
"xz9.com",
"yaboo.dk",
"yaninediaz.com",
"ybuano.org",
"yellowmonkey.com",
"yellowmonkey2.com",
"yellowmonkey55.com",
"yelucie.com",
"yisosky.vip.sina.com",
"ymf.name",
"yoga-mats.freeservers.com",
"yoll.net",
"you-date.com",
"young-ass.us",
"your-tattoo.de",
"yourcialis.info",
"yourdentalinsuranceonline.com",
"yourowncolours.co.uk",
"yourserver.com",
"ypoker.net",
"yubatech.com",
"yukka.inc.ru",
"zalaszentgrot.com",
"zaotao.com",
"zazlibrary.com",
"zenno.info",
"zfgfz.net",
"zipcodedownload.com",
"zipcodesmap.com",
"zithromax-online.net",
"zj.com",
"zone-b51.com",
"zoo-sex-pics.com",
"zoo-sex.biz",
"zoo-sex.info",
"zoo-zone.com",
"zooeurope.com",
"zoofil.com",
"zoofilia-fotos.com",
"zoomaniz.flnet.org",
"zoosex-motion-videos.com",
"zoosex-pictures.com",
"zoosx.net",
"zpics.net",
"zt148.com",
"zum-bestpreis.de",
"zweree.com",
"zxyzxy.com",
"anal-sex",
"gambiling-online",
"gambling-online",
"mc.ashgabad.su",
"smokersteeth.com",
"ibizatopless.com",
"holdem-poker.us.gg",
"hotelgaydays.com",
"lenarcic.org",
"poker4spain.com",
"vneighbor.com",
};


